# frozen_string_literal: true

module PlanetExpress
  class ShippingOptionRepository < Repository
    attr_reader :data

    def initialize(data: nil)
      @data = data || default_data
      calculate_provider_size_lookup_table
    end

    def find_by_provider_and_package_size(provider, package_size)
      provider_size_lookup_table[[provider, package_size]]&.first
    end

    def lowest_price_for_package_size(package_size)
      where(package_size: package_size).map(&:price_in_cents).min
    end

    private
    attr_reader :provider_size_lookup_table

    def default_data
      [
        ShippingOption.new('LP', 'S', 150),
        ShippingOption.new('LP', 'M', 490),
        ShippingOption.new('LP', 'L', 690),
        ShippingOption.new('MR', 'S', 200),
        ShippingOption.new('MR', 'M', 300),
        ShippingOption.new('MR', 'L', 400)
      ]
    end

    def calculate_provider_size_lookup_table
      @provider_size_lookup_table = data.group_by do |option|
        [option.provider, option.package_size]
      end
    end
  end
end
